@@ -23,6 +23,8 @@ a real actual sftp server is contacted, and a new folder is created there to
 do test file operations in (so no existing files will be harmed).
 """
 
+from __future__ import with_statement
+
 from binascii import hexlify
 import logging
 import os
@@ -36,6 +38,7 @@ import unittest
 import paramiko
 from stub_sftp import StubServer, StubSFTPServer
 from loop import LoopSocket
+from paramiko.sftp_attr import SFTPAttributes
 
 ARTICLE = '''
 Insulin sensitivity and liver insulin receptor structure in ducks from two
@@ -187,6 +190,17 @@ class SFTPTest (unittest.TestCase):
         finally:
             sftp.remove(FOLDER + '/duck.txt')
 
+    def test_3_sftp_file_can_be_used_as_context_manager(self):
+        """
+        verify that an opened file can be used as a context manager
+        """
+        try:
+            with sftp.open(FOLDER + '/duck.txt', 'w') as f:
+                f.write(ARTICLE)
+            self.assertEqual(sftp.stat(FOLDER + '/duck.txt').st_size, 1483)
+        finally:
+            sftp.remove(FOLDER + '/duck.txt')
+
     def test_4_append(self):
         """
         verify that a file can be opened for append, and tell() still works.
@@ -667,6 +681,33 @@ class SFTPTest (unittest.TestCase):
         finally:
             sftp.unlink(FOLDER + '/zero')
 
+    def test_N_put_without_confirm(self):
+        """
+        verify that get/put work without confirmation.
+        """
+        import os, warnings
+        warnings.filterwarnings('ignore', 'tempnam.*')
+
+        localname = os.tempnam()
+        text = 'All I wanted was a plastic bunny rabbit.\n'
+        f = open(localname, 'wb')
+        f.write(text)
+        f.close()
+        saved_progress = []
+        def progress_callback(x, y):
+            saved_progress.append((x, y))
+        res = sftp.put(localname, FOLDER + '/bunny.txt', progress_callback, False)
+        
+        self.assertEquals(SFTPAttributes().attr, res.attr)
+
+        f = sftp.open(FOLDER + '/bunny.txt', 'r')
+        self.assertEquals(text, f.read(128))
+        f.close()
+        self.assertEquals((41, 41), saved_progress[-1])
+
+        os.unlink(localname)
+        sftp.unlink(FOLDER + '/bunny.txt')
+
     def XXX_test_M_seek_append(self):
         """
         verify that seek does't affect writes during append.
